@@ -1,6 +1,6 @@
 package ScriptTestApp::TraitFor::Script;
 use Moose::Role;
-use namespace::autoclean;
+use namespace::clean -except => [ 'meta' ];
 
 around run => sub {
     my ($orig, $self, @args) = @_;
