@@ -1,6 +1,6 @@
 package TestPath::Controller::Two;
 use Moose;
-use namespace::autoclean;
+use namespace::clean -except => [ 'meta' ];
 
 BEGIN { extends 'Catalyst::Controller' }
 
@@ -9,4 +9,4 @@ sub two :Path() {
     $c->response->body( 'OK' );
 }
 
-__PACKAGE__->meta->make_immutable;
\ No newline at end of file
+__PACKAGE__->meta->make_immutable;
